BOAVUS
======
Analysis of ECoG and fMRI data in Python based on BIDS

Features
--------
- Pure Python

Installation
------------
Install won by running:

    pip install boavus

Requirements
------------
- Python 3.6
- bidso
- fsl
- freesurfer

License
-------
The project is licensed under the MIT license.
